## chanzap_chanremoved.dpatch by Tzafrir Cohen <tzafrir.cohen@xorcom.com>
##
## Destroy a channel in response to ZT_EVENT_REMOVED

@DPATCH@
diff -urNad asterisk-1.2.7.1.dfsg/channels/chan_zap.c /tmp/dpep.4Is537/asterisk-1.2.7.1.dfsg/channels/chan_zap.c
--- asterisk-1.2.7.1.dfsg/channels/chan_zap.c	2006-06-20 12:18:47.528883972 +0300
+++ /tmp/dpep.4Is537/asterisk-1.2.7.1.dfsg/channels/chan_zap.c	2006-06-20 12:20:05.174982051 +0300
@@ -107,6 +107,11 @@
 #define ZT_EVENT_DTMFUP 0
 #endif
 
+/* FIXME: a temporary def until zaptel.h is synced */
+#ifndef ZT_EVENT_REMOVED
+#define ZT_EVENT_REMOVED (20)
+#endif
+
 /* define this to send PRI user-user information elements */
 #undef SUPPORT_USERUSER
 
@@ -357,6 +362,8 @@
 
 static int zt_sendtext(struct ast_channel *c, const char *text);
 
+static int zap_destroy_channel_bynum(int channel);
+
 /*! \brief Avoid the silly zt_getevent which ignores a bunch of events */
 static inline int zt_get_event(int fd)
 {
@@ -6535,6 +6542,11 @@
 				"polarity reversal on non-FXO (SIG_FXS) "
 				"interface %d\n", i->channel);
 		}
+	case ZT_EVENT_REMOVED: /* destroy channel */
+		ast_log(LOG_NOTICE, 
+			"Got ZT_EVENT_REMOVED. Destroying channel %d\n", 
+			i->channel);
+		zap_destroy_channel_bynum(i->channel);
 	}
 	return 0;
 }
@@ -9632,17 +9644,12 @@
 
 #endif
 
-static int zap_destroy_channel(int fd, int argc, char **argv)
+/* destroy a zaptel channel, identified by its number */
+static int zap_destroy_channel_bynum(int channel)
 {
-	int channel = 0;
 	struct zt_pvt *tmp = NULL;
 	struct zt_pvt *prev = NULL;
 	
-	if (argc != 4) {
-		return RESULT_SHOWUSAGE;
-	}
-	channel = atoi(argv[3]);
-
 	tmp = iflist;
 	while (tmp) {
 		if (tmp->channel == channel) {
@@ -9696,6 +9703,18 @@
 	return 0;
 }
 
+static int zap_destroy_channel(int fd, int argc, char **argv)
+{
+	int channel = 0;
+	
+	if (argc != 4) {
+		return RESULT_SHOWUSAGE;
+	}
+	channel = atoi(argv[3]);
+
+	return zap_destroy_channel_bynum(channel);
+}
+
 static int zap_show_channels(int fd, int argc, char **argv)
 {
 #define FORMAT "%7s %-10.10s %-15.15s %-10.10s %-20.20s\n"
